C ESA (C) 2000-2018 
C
C This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
C
C    SAS is free software: you can redistribute it and/or modify
C    it under the terms of the GNU General Public License as published by
C    the Free Software Foundation, either version 3 of the License, or
C    (at your option) any later version.
C
C    SAS is distributed in the hope that it will be useful,
C    but WITHOUT ANY WARRANTY; without even the implied warranty of
C    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C    GNU General Public License for more details.
C
C    You should have received a copy of the GNU General Public License
C    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
      subroutine d_lookup(siabsd, sloss_alpha, sloss_beta)
c
c Calculate the surface loss lookup tables. There are ndmax-1 linear
c depth increments between depth = 0.0 and depth = depth1 (where the
c surface loss fraction = 1.0).
c
c  Local Variables
      implicit none

      integer i

      real siabsd, sloss_alpha, sloss_beta
      real depth, depth1, depthinc
      real dnorm_new, dnorm_old, dvar
      real fracd_new, fracd_old
      real fracd_lookup(100), dnorm_lookup(100)
c
c  Local Constants
      integer ndmax

      real dpl_depth
      parameter(dpl_depth = 35.0)
c
c  External Functions
      real sloss_fraction
c
c  Common Parameters
      common /fracd_lookup/ fracd_lookup
      common /dnorm_lookup/ dnorm_lookup
      common /ndmax/ ndmax

      ndmax = 40

      fracd_old = sloss_alpha

      depth = 0.0

      if(sloss_beta .eq. 0.0) then
          depth1 = dpl_depth
      else
          depth1 = (1.0 - sloss_alpha) / sloss_beta
      endif
      depthinc = depth1 / float(ndmax-2)        
        
      dnorm_old = 0.0

      do i = 2, ndmax-1
        depth = depth + depthinc

        fracd_new = sloss_fraction(depth, sloss_alpha, sloss_beta)
        fracd_lookup(i) = 0.5 * (fracd_new + fracd_old)
        fracd_old = fracd_new

        dvar = depth / siabsd
        if(dvar .lt. 50.0) then
            dnorm_new = 1.0 - exp(-1.0 * dvar)
        else
            dnorm_new = 1.0
        endif
        dnorm_lookup(i) = dnorm_new - dnorm_old
        dnorm_old = dnorm_new
      enddo

      fracd_lookup(ndmax) = 1.0

      dvar = dpl_depth / siabsd
      if(dvar .lt. 50.0) then
          dnorm_new = 1.0 - exp(-1.0 * dvar)
      else
          dnorm_new = 1.0
      endif
      dnorm_lookup(ndmax) = dnorm_new - dnorm_old

      return
      end



