C ESA (C) 2000-2018 
C
C This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
C
C    SAS is free software: you can redistribute it and/or modify
C    it under the terms of the GNU General Public License as published by
C    the Free Software Foundation, either version 3 of the License, or
C    (at your option) any later version.
C
C    SAS is distributed in the hope that it will be useful,
C    but WITHOUT ANY WARRANTY; without even the implied warranty of
C    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C    GNU General Public License for more details.
C
C    You should have received a copy of the GNU General Public License
C    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
      subroutine pinterp(e0, ein, nin, parin, ip, grade, limit, pval)
c
c Derives the parameters, p, at energy e0, by interpolation from the
c parameters in array, param calculated at energies, e
c

      implicit none

      integer i, j1, j2
      integer ne, nin, ip, grade
      integer np, nemax, ng
      parameter(np = 13, nemax = 200, ng=6)

      real parin(np, nemax, ng)
      real ein(nemax), e(nemax), param(nemax) 
      real e0, pval, limit
      real v1, v2, v3
      real si_kedge, si_kalpha

      logical notfound

      common /silicon/ si_kedge, si_kalpha

c
c Exclude all normalisation = 0 points from the param array
c
      ne = 0
      do i = 1, nin
        if (parin(1, i, grade) .gt. 0.0) then
          ne = ne + 1
          e(ne) = ein(i)
          param(ne) = parin(ip, i, grade)
        endif
      enddo
c
c End points. Extrapolate from nearest two bins
c
      if (e0 .le. e(1)) then 
        v1 = param(2) - param(1)
        v2 = e(2) - e(1)
        v3 = e(2) - e0
        pval = param(2) - ((v1 / v2) * v3)
        if (pval .lt. limit) then
          pval = limit
        endif
        return
      endif

      if (e0 .ge. e(ne)) then
        j1 = ne - 1
        v1 = param(ne) - param(j1)
        v2 = e(ne) - e(j1)
        v3 = e(ne) - e0
        pval = param(ne) - ((v1 / v2) * v3)
        if (pval .lt. limit) then
          pval = limit
        endif
        return
      endif

c
c Loop through rest of array and find the bins which cover e0
c
      notfound = .true.
      j1 = int(float(ne) - ((ne-1) * (e(ne) - e0) / (e(ne) - e(1))))
      dowhile (notfound)
        j2 = j1 + 1
        if ((e0 .ge. e(j1)) .and. (e0 .lt. e(j2))) then
          notfound = .false.
        else
          if (e0 .lt. e(j1)) then
            j1 = j1 - 1
          else
            j1 = j1 + 1
          endif
        endif
        if ((j1 .lt. 1) .or. (j1 .ge. ne)) then 
          write(*,*) 'LOGIC ERROR'
          write(*,*) e0, j1, ne
          return
        endif
      enddo
c
c Check whether bounding Silicon edge and adjust j1 and j2 so that you
c extrapolate rather than interpolate
c
      if ((e(j1) .le. si_kedge) .and. (e(j2) .gt. si_kedge)) then
        if (e0 .le. si_kedge) then
          j1 = j1 - 1
        else
          j1 = j1 + 1
        endif
        j2 = j1 + 1
      endif

      v1 = param(j2) - param(j1)
      v2 = e(j2) - e(j1)
      v3 = e(j2) - e0
      pval = param(j2) - ((v1 / v2) * v3)
      if (pval .lt. limit) then
        pval = limit
      endif

      return
      end
 
