C ESA (C) 2000-2018 
C
C This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
C
C    SAS is free software: you can redistribute it and/or modify
C    it under the terms of the GNU General Public License as published by
C    the Free Software Foundation, either version 3 of the License, or
C    (at your option) any later version.
C
C    SAS is distributed in the hope that it will be useful,
C    but WITHOUT ANY WARRANTY; without even the implied warranty of
C    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C    GNU General Public License for more details.
C
C    You should have received a copy of the GNU General Public License
C    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
      real function redgauss(e1, e0, sigma, red_sigma)
c
c Returns the unormalised value of a Gaussian with a red tail. This is
c modelled simply by having an additive second Gaussian when e1 < e0.
c The second Gaussian has a width = sigma*red_sigma
c
      implicit none

c  Local Variables
      real e1, e0, sigma, sigma2, red_sigma
      real var1, var2, comp1, comp2

c  Local Constants
      real dsq2pi
      parameter(dsq2pi = 2.50662827463)
      real threshold
      parameter (threshold = 23.0)

c  External Functions

c  Common Parameters

c-
      if (e1 .ge. e0) then
          var1 = ((e1-e0)/sigma)**2
          if( var1 .lt. threshold ) then
              redgauss = (1.0/(sigma*dsq2pi)) * exp(-0.5 * var1)
          else
              redgauss = 0.0
          endif
      else
          sigma2 = sigma * red_sigma
          var1 = ((e1-e0)/sigma)**2
          var2 = ((e1-e0)/sigma2)**2
          if( var1 .lt. threshold ) then
              comp1 = (1.0/(sigma*dsq2pi)) * exp(-0.5 * var1)
          else
              comp1 = 0.0
          endif
          if( var2 .lt. threshold ) then
              comp2 = (1.0/(sigma2*dsq2pi)) * exp(-0.5 * var2)
          else
              comp2 = 0.0
          endif
          redgauss = (sigma2 / (sigma+sigma2)) * (comp1 + comp2)
      endif

      return
      end





