C ESA (C) 2000-2018 
C
C This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
C
C    SAS is free software: you can redistribute it and/or modify
C    it under the terms of the GNU General Public License as published by
C    the Free Software Foundation, either version 3 of the License, or
C    (at your option) any later version.
C
C    SAS is distributed in the hope that it will be useful,
C    but WITHOUT ANY WARRANTY; without even the implied warranty of
C    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C    GNU General Public License for more details.
C
C    You should have received a copy of the GNU General Public License
C    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
      subroutine response(model, ech, 
     &                    main_norm, main_energy, main_sigma,
     &                    red_sigma, shelf_norm, lowe_norm, lowe_sigma,
     &                    flo_norm, flo_sigma, esc_norm, esc_sigma,
     &                    rmf)
c
c  Returns the response at energy, ech.
c
c  The possible free model parameters are
c     main_norm      - Normalisation of main photopeak
c     main_energy    - Energy of mainphotopeak
c     main_sigma     - Width of spread main function
c     red_sigma      - Relative sigma of "red" tail in redgauss model
c     shelf_norm     - Relative normalisation of shelf function
c     lowe_norm      - Relative normalisation of low-energy component
c     lowe_sigma     - Sigma of low-energy component
c     flo_norm       - Relative normalisation of fluoresence peak
c     flo_sigma      - Width of fluoresence peak
c     esc_norm       - Relative normalisation of escape peak
c     esc_sigma      - Width of escape peak
c     
c
c  Last Modified:
c      7-Apr-2000
c     30-May-2000: (sse) Lorentz function now fitted to low energy component
c     21-Sep-2000: (sse) redgauss model now applied to sloss function
c      6-Dec-2000: (sse) Compatible with v4.0
c
c  Local Variables
      implicit none

      integer model    

      real ech, rmf1, rmf2, rmf3, rmf

      real main_norm     
      real main_energy   
      real main_sigma    
      real red_sigma
      real shelf_norm    
      real lowe_norm     
      real lowe_sigma
      real lowe_energy
      parameter(lowe_energy = 100.0)
      real flo_norm      
      real flo_sigma     
      real esc_norm      
      real esc_sigma     
c
c  External Functions
      real si_gauss_sloss
      real si_redgauss_sloss
      real si_redgauss
      real lorentz
      real shelf

       write(*,*)'MODEL: ',model
c
c Select chosen model
c
      if ((model .eq. 0) .or. (model .eq. 1)) then
c
c Gauss model modified by surface loss with additional low energy 
c and shelf components
c
        rmf1 = si_gauss_sloss(ech, main_energy, main_sigma,
     1                             flo_norm, flo_sigma,
     2                             esc_norm, esc_sigma)

        rmf2 = shelf_norm * shelf(ech, main_energy, main_sigma, 0.0d0)
        rmf3 = lowe_norm * lorentz(ech, lowe_energy, lowe_sigma)
        rmf = main_norm * (rmf1 + rmf2 + rmf3) 

      elseif ((model .eq. 2 ) .or. (model .eq. 3)) then
c
c Gauss model modified by surface loss with additional shelf component
c
        rmf1 = si_gauss_sloss(ech, main_energy, main_sigma,
     1                             flo_norm, flo_sigma,
     2                             esc_norm, esc_sigma)

        rmf2 = shelf_norm * shelf(ech, main_energy, main_sigma, 0.0d0)
        rmf = main_norm * (rmf1 + rmf2) 

      elseif ((model .eq. 4) .or. (model .eq. 5)) then
c
c Red-Gauss Model only
c
        rmf = main_norm * si_redgauss(ech, main_energy, main_sigma,
     1                                red_sigma, flo_norm, flo_sigma,
     2                                esc_norm, esc_sigma)


      elseif ((model .eq. 6) .or. (model .eq. 7)) then
c
c Red-Gauss model modified by surface loss with additional low energy 
c and shelf components
c
        rmf1 = si_redgauss_sloss(ech, main_energy, main_sigma,
     1                                red_sigma, flo_norm, flo_sigma,
     2                                esc_norm, esc_sigma)
        rmf2 = shelf_norm * shelf(ech, main_energy, main_sigma, 0.0d0)
        rmf3 = lowe_norm * lorentz(ech, lowe_energy, lowe_sigma)
        rmf = main_norm * (rmf1 + rmf2 + rmf3) 

      elseif ((model .eq. 8) .or. (model .eq. 9)) then
c
c Red-Gauss model modified by surface loss with additional shelf component
c
        rmf1 = si_redgauss_sloss(ech, main_energy, main_sigma,
     1                                red_sigma, flo_norm, flo_sigma,
     2                                esc_norm, esc_sigma)

        rmf2 = shelf_norm * shelf(ech, main_energy, main_sigma, 0.0d0)
        rmf = main_norm * (rmf1 + rmf2) 

      endif

      return
      end







