C ESA (C) 2000-2018 
C
C This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
C
C    SAS is free software: you can redistribute it and/or modify
C    it under the terms of the GNU General Public License as published by
C    the Free Software Foundation, either version 3 of the License, or
C    (at your option) any later version.
C
C    SAS is distributed in the hope that it will be useful,
C    but WITHOUT ANY WARRANTY; without even the implied warranty of
C    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C    GNU General Public License for more details.
C
C    You should have received a copy of the GNU General Public License
C    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
      real function si_gauss_sloss(e1, main_energy, main_sigma, 
     1                               flo_norm, flo_sigma, 
     2                               esc_norm, esc_sigma)
c
c Returns the unormalised value of the integral of a Gaussian Si response 
c modified by a surface loss model.
c
c  Local Variables
      implicit none

      integer i, ndmax

      real main_energy, main_sigma
      real flo_norm, flo_sigma, esc_norm, esc_sigma
      real main, siflo, siesc
      real e1, e0, flo_e0, esc_e0

      real dnorm_lookup(100), fracd_lookup(100)
c
c  Local Constants
      real si_kedge, si_kalpha
c
c  External Functions
      real gauss
c
c  Common Parameters
      common /dnorm_lookup/ dnorm_lookup
      common /fracd_lookup/ fracd_lookup
      common /ndmax/ ndmax
      common /silicon/ si_kedge, si_kalpha

      si_gauss_sloss = 0.0
      do i = 2, ndmax
          e0 = main_energy * fracd_lookup(i)
          main = gauss(e1, e0, main_sigma)

          if (main_energy .gt. si_kedge) then
              flo_e0 = si_kalpha * fracd_lookup(i)
              siflo = flo_norm * gauss(e1, flo_e0, flo_sigma) 

              esc_e0 = e0 - si_kalpha
              siesc = esc_norm * gauss(e1, esc_e0, esc_sigma) 
              si_gauss_sloss = si_gauss_sloss + 
     &                         (dnorm_lookup(i)*(main + siflo + siesc)) 
          else
              si_gauss_sloss = si_gauss_sloss + (dnorm_lookup(i)*main) 
          endif

      enddo

      return
      end
